#
# The Qubes OS Project, http://www.qubes-os.org
#
# Copyright (C) 2015  Marek Marczykowski-Górecki
#                       <marmarek@invisiblethingslab.com>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#

Name:           qubes-kernel-vm-support
Version:        4.3.3
Release:        1%{?dist}
Summary:        Qubes VM initramfs modules
Source0:        qubes-utils-%{version}.tar.gz

Group:          Qubes
Vendor:         Invisible Things Lab
License:        GPL v2 only
URL:            http://www.qubes-os.org

# qubes-prepare-vm-kernel interface version - to use in kernel.spec
Provides:       qubes-prepare-vm-kernel = 2
Requires:       dracut
Requires:       busybox
Requires:       e2fsprogs
BuildRequires:  make
BuildRequires:  gcc
BuildRequires:  e2fsprogs-devel
%if 0%{?is_opensuse}
# for directory ownership
BuildRequires: dracut
%endif

%description
This package contains:
1. Dracut module required to setup Qubes VM root filesystem. This package is
needed in VM only when the VM uses its own kernel (via pvgrub or so). Otherwise
initrd is provided by dom0.

%prep
%setup -q -n qubes-utils-%{version}

%build
make -C kernel-modules all

%install
make install-fedora-kernel-support DESTDIR=%{buildroot}

%files
%dir %{_prefix}/lib/qubes
/usr/lib/dracut/modules.d/90qubes-vm
/usr/lib/dracut/modules.d/90qubes-vm-modules
/usr/lib/dracut/modules.d/90qubes-vm-simple
/usr/lib/dracut/modules.d/80xen-scrub-pages
/usr/lib/qubes/vm-modules-genfs
/usr/sbin/qubes-prepare-vm-kernel
%config(noreplace) /etc/default/grub.qubes-kernel-vm-support

%triggerin -- grub2-tools
if ! grep -q '/etc/default/grub\.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
    # do not keep Qubes-related settings directly in user-controlled config,
    # include another file
    echo '. /etc/default/grub.qubes-kernel-vm-support' >> /etc/default/grub
fi

%preun
if [ $1 -eq 0 ]; then
    if grep -q '/etc/default/grub\.qubes-kernel-vm-support$' /etc/default/grub 2>/dev/null; then
        sed -i -e '/grub\.qubes-kernel-vm-support$/d' /etc/default/grub
    fi
fi

%posttrans

# Rebuild all initramfs images to include updated modules
if [ -r /usr/share/qubes/marker-vm ] && [ -x /usr/bin/dracut ]; then
    ret=0
    for img in /boot/initramfs-*.img; do
        kver="${img#*initramfs-}"
        kver="${kver%.img}"
        dracut -f "$img" "$kver" || ret=$?
    done
    if [ "$ret" -eq 0 ]; then
        # "milestone" initramfs update version:
        # 1 - addition of xen scrub_pages enabling code
        echo 1 > /var/lib/qubes/initramfs-updated
    fi
fi

%changelog
* Fri Jul 05 2024 Qubes OS Team <qubes-devel@googlegroups.com>
- For complete changelog see: https://github.com/QubesOS/qubes-linux-utils.git

* Fri Jul 05 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c9b25d6
- version 4.3.3

* Sat Jun 22 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 973fe96
- Do not redefine compiler flags that are up to build env to define

* Mon Jun 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c231fe5
- version 4.3.2

* Mon Jun 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ff76ff4
- debian: bump required versions for libs

* Mon Jun 17 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - c7dbb73
- version 4.3.1

* Sat Jun 15 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 044c4d4
- Don't allow trailing slashes in paths being unpacked

* Sat Jun 15 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - aa0b85e
- Allow disabling symbolic link checking

* Sat Jun 15 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - af7ae9b
- Add flag to allow non-canonical symbolic links

* Sat Jun 15 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 17c27ac
- Use for loop instead of do-while

* Sat Jun 15 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 5dcc596
- Improve symlink tests

* Sat Jun 15 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - aa2466c
- Allow disabling character set filtering

* Sat Jun 15 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 34172df
- Better error message for forbidden symbolic links

* Sat Jun 15 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 1a659f8
- version 4.3.0

* Sat Jun 15 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - e8669db
- ci: update tags

* Mon May 20 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 075dfe4
- Do not use fchmodat() because it follows symlinks

* Mon May 20 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - edece29
- Do not use path containing "/" in linkat() or stat()

* Mon May 20 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 2a0da19
- Avoid redundantly validating symbolic link names

* Mon May 20 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 188b608
- Fix -Wmissing-declarations and -Wmissing-prototypes warnings

* Mon May 20 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 0070e55
- Avoid casting away const when not needed

* Mon May 20 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - cb5c376
- Document the pretty-printer in the code generator

* Mon May 20 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - a656698
- Move path validation tests before charset tests

* Mon May 20 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 9f78bc4
- Test that symbolic links can end in '/'

* Mon May 20 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 34c92b5
- Allow symlinks ending in ".."

* Mon May 20 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - f0f23af
- Document algorithm used to sanitize paths

* Wed May 08 2024 Piotr Bartman <prbartman@invisiblethingslab.com> - 3ad3bb2
- q-dev: add data to qubesdb needed by new API

* Thu May 02 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5582539
- version 4.2.16

* Tue Jan 09 2024 Demi Marie Obenour <demi@invisiblethingslab.com> - 4e9e357
- Math and currency symbols are safe for display

* Thu Jan 04 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ba9b37e
- Switch to sequoia for codecov signature check

* Thu Jan 04 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5dc579d
- Fix imgconverter tests

* Wed Jan 03 2024 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5961672
- ci: collect test coverage from qrexec-lib too

* Mon Dec 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 5df5616
- version 4.2.15

* Sun Dec 03 2023 Rusty Bird <rustybird@net-c.com> - 13a0ede
- qrexec-lib/pack: sanitize straight quotes in remote filenames

* Sat Dec 02 2023 Rusty Bird <rustybird@net-c.com> - 71f5b04
- qrexec-lib/pack: don't use curly quotes in error messages

* Mon Nov 13 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - b1e335a
- Avoid writing junk into Xenstore

* Sun Nov 05 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 24cdce9
- rpm: adjust dependencies for openSUSE

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - ad0b68b
- genfs: fix build/link flags

* Sat Nov 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - bc62e92
- rpm: fix missing directory ownership

* Wed Sep 27 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 96698e2
- version 4.2.14

* Wed Sep 27 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - f89a3b8
- Block Zalgo text

* Sun Sep 24 2023 Rusty Bird <rustybird@net-c.com> - 3ee5516
- qrexec-lib/unpack: fail on EOF before end of transfer marker

* Sun Sep 17 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 3925e82
- Expose code point allowlist checking API

* Sun Sep 10 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6c4902e
- version 4.2.13

* Sun Aug 20 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 6fe6fac
- version 4.2.12

* Wed Aug 16 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 711e416
- Drop unmaintained asynctest library

* Mon Aug 14 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 6f4f1ab
- Make qubes_pure_string_safe_for_display() usable

* Fri Aug 11 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - 26c3e30
- debian: split libqubes-pure into separate package

* Fri Aug 11 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 65bc3f4
- Test rejection of codepoints past 0x10FFFFF

* Thu Aug 10 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - 2cd3547
- Stricter symbolic link checks

* Thu Aug 10 2023 Demi Marie Obenour <demi@invisiblethingslab.com> - b1c9bb6
- Link against just-built libqubes-pure

* Tue Jul 04 2023 Marek Marczykowski-Górecki <marmarek@invisiblethingslab.com> - d4c9805
- version 4.2.11

